TrackCookies

Struct TrackCookies 

pub struct TrackCookies<T> { /* private fields */ }
A structure that tracks cookies for requests and responses.

This structure manages cookies according to RFC 6265. it is not fully compliant (it doesn’t check the secure flag, doesn’t purge expired entries) but should be good enough for just talking to porkbun.

Implementations

Source

impl<T> TrackCookies<T>

pub fn wrapping(inner: T) -> Self

Creates a new TrackCookies instance.